@@ -25,6 +25,8 @@
 
 import gpodder
 
+_ = gpodder.gettext
+
 from gpodder import util
 
 import logging
@@ -44,13 +46,19 @@ MOOGALOOP_RE = re.compile(r'http://vimeo\.com/moogaloop\.swf\?clip_id=(\d+)$', r
 SIGNATURE_RE = re.compile(r'"timestamp":(\d+),"signature":"([^"]+)"')
 DATA_CONFIG_RE = re.compile(r'data-config-url="([^"]+)"')
 
+# List of qualities, from lowest to highest
+FILEFORMAT_RANKING = ['mobile', 'sd', 'hd']
+
+FORMATS = (
+        ('mobile', _('Mobile')),
+        ('sd', _('SD')),
+        ('hd', _('HD')),
+)
+
 
 class VimeoError(BaseException): pass
 
-def get_real_download_url(url):
-    quality = 'sd'
-    codecs = 'H264,VP8,VP6'
-
+def get_real_download_url(url, preferred_fileformat=None):
     video_id = get_vimeo_id(url)
 
     if video_id is None:
@@ -78,8 +86,21 @@ def get_real_download_url(url):
 
                 yield (fileformat, keys['url'])
 
-    for quality, url in get_urls(data_config_url):
-        return url
+    fileformat_to_url = dict(get_urls(data_config_url))
+
+    if preferred_fileformat is not None and preferred_fileformat in fileformat_to_url:
+        logger.debug('Picking preferred format: %s', preferred_fileformat)
+        return fileformat_to_url[preferred_fileformat]
+
+    def fileformat_sort_key_func(fileformat):
+        if fileformat in FILEFORMAT_RANKING:
+            return FILEFORMAT_RANKING.index(fileformat)
+
+        return 0
+
+    for fileformat in sorted(fileformat_to_url, key=fileformat_sort_key_func, reverse=True):
+        logger.debug('Picking best format: %s', fileformat)
+        return fileformat_to_url[fileformat]
 
 def get_vimeo_id(url):
     result = MOOGALOOP_RE.match(url)
